package com.supplier.mapper;

import com.supplier.model.*;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface SupplierReleaseMapper{
    void addRelease(SupplierRelease supplierRelease);

    void addReleaseDay(SupplierReleaseDay supplierReleaseDay);

    void addReleasePlay(SupplierReleasePlay supplierReleasePlay);

    List<SupplierRelease> getSupplierRelease(SupplierRelease supplierRelease);

    List<SupplierReleaseDay> getSupplierReleaseDay(String uuid);

    List<SupplierReleasePlay> getSupplierReleasePlay(String uuid);

    void delSupplierReleaseDay(SupplierRelease supplierRelease);

    void delSupplierReleasePlay(SupplierRelease supplierRelease);

    void updateSupplierRelease(SupplierRelease supplierRelease);

    void addPrivateType(SupplierRelease supplierRelease);

    void updatePrivateType(SupplierRelease supplierRelease);

    ConfirmOrdering getConfirmOrdering(ConfirmOrdering confirmOrdering);

    List<UsedUser> getConfirmUsed(String uuid);

    List<SupplierRelease> getSupplierReleaseType(String demandUuid);

    void updateSupplierOffer(SupplierRelease supplierRelease2);

    ConfirmOrdering getConfirmOrderingUser(ConfirmOrdering confirmOrdering);

    String getReleasOrderType(SupplierRelease supplierRelease);

    String getSupplierOrderType(SupplierRelease supplierRelease1);
}
